# Run python get.py
# Get the rules from profiles
import os, glob

if __name__ == "__main__":

    current_dir = os.path.abspath( __file__ )[:-6]
    dir = current_dir + '../data/app_profiles'
    all_categories = []
    os.chdir(dir)
    
    fw = open(current_dir + 'extra_translations.py', 'w')
    fw.write("%s\n" % 'import gettext')
    fw.write("%s\n" % 'from gettext import gettext as _')
    fw.write("%s\n" % 'gettext.textdomain("gufw")')
    fw.write("%s\n" % 'if __name__ == "__main__":')
    for file in glob.glob("*.*"):
        # Extract data for each service
        title = ''
        description = ''
        ports = ''
        categories = ''
        warning = ''
        f = open(file, 'r')
        for line in f:
            line = line.replace('\n', '')
            if 'title=' in line:
                title = line.replace('title=', '')
            if 'description=' in line:
                description = line.replace('description=', '')
            if 'ports=' in line:
                ports = line.replace('ports=', '')
            if 'categories=' in line:
                categories = line.replace('categories=', '')
            if 'warning=' in line:
                warning = line.replace('warning=', '')

            # Done
            if title and description and ports and categories:
                fw.write("    print(_(\"%s\"))\n" % title)
                fw.write("    print(_(\"%s\"))\n" % description)
                if all_categories.count(categories) == 0:
                    fw.write("    print(_(\"%s\"))\n" % categories)
                    all_categories.append(categories)
                if warning:
                    fw.write("    print(_(\"%s\"))\n" % warning)
                title = ''
                description = ''
                ports = ''
                categories = ''
                warning = ''
    fw.write("    print(_(\"%s\"))\n" % 'Authentication is required to run the Firewall Configuration')
    fw.write("    print(_(\"%s\"))\n" % 'Firewall Configuration')
    fw.write("    print(_(\"%s\"))\n" % 'An easy way to configure your firewall')
    fw.close()



import gettext
from gettext import gettext as _
gettext.textdomain("gufw")
if __name__ == "__main__":
    print(_("Soldier of Fortune"))
    print(_("Soldier of Fortune - A FPS by Raven Software"))
    print(_("Games;Action;"))
    print(_("Castle-Combat - 50386/tcp"))
    print(_("A clone of Rampart from Atari Games"))
    print(_("Games;Arcade;"))
    print(_("Castle-Combat - 8787/tcp"))
    print(_("A clone of Rampart from Atari Games"))
    print(_("GNUnet"))
    print(_("A decentralized peer-to-peer networking framework with file sharing and messaging"))
    print(_("Network;File Transfer;"))
    print(_("netPanzer"))
    print(_("An online multiplayer tactical warfare game"))
    print(_("Postal"))
    print(_("Violent combat game from Running With Scissors"))
    print(_("Diablo II"))
    print(_("Fantasy combat game by Blizzard Entertainment"))
    print(_("Webmin"))
    print(_("Web-page based system management utility"))
    print(_("Network;Shell;"))
    print(_("Webmin fast RPC"))
    print(_("Web-page based system management utility"))
    print(_("Counter-Strike 2D"))
    print(_("A top-down 2D clone of Valve Software's Counter-Strike by Unreal Software"))
    print(_("TeamSpeak 2 voice"))
    print(_("TeamSpeak 2 voice service"))
    print(_("Network;Telephony;"))
    print(_("TeamSpeak 2 web"))
    print(_("TeamSpeak 2 web interface"))
    print(_("TeamSpeak 2 TCP query"))
    print(_("TeamSpeak 2 TCP query"))
    print(_("Skype - 23399"))
    print(_("VoIP client"))
    print(_("Skype - 23398"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23397"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23396"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23395"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23394"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23393"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23392"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23391"))
    print(_("VoIP client, suggested alternate port"))
    print(_("Skype - 23390"))
    print(_("VoIP client, suggested alternate port"))
    print(_("SIP"))
    print(_("Session Initiation Protocol, unencrypted, using nf_conntrack_sip module"))
    print(_("SIP TLS"))
    print(_("Session Initiation Protocol with TLS encryption"))
    print(_("MiniDLNA"))
    print(_("Serves media files (music, pictures, and video) to clients on a network"))
    print(_("Audio Video;TV;"))
    print(_("iMaze"))
    print(_("A maze combat game in 3D"))
    print(_("Crossfire"))
    print(_("An open source, cooperative multiplayer graphical RPG and adventure game"))
    print(_("Games;Role;"))
    print(_("Crossfire Metaserver"))
    print(_("Metaserver for Crossfire RPG"))
    print(_("World of Warcraft"))
    print(_("A MMORPG game by Blizzard Entertainment"))
    print(_("Descent 3"))
    print(_("3D Flying FPS by Outrage Entertainment"))
    print(_("Widelands"))
    print(_("A RTS similar to The Settlers I & II from Blue Byte Software"))
    print(_("Games;Strategy;"))
    print(_("MythTV"))
    print(_("MythTV backend"))
    print(_("Mechwarrior 4"))
    print(_("A FPS based on the Fasa Battletech universe"))
    print(_("FreeOrion"))
    print(_("A turn-based 4X strategy game inspired by Master of Orion from MicroProse"))
    print(_("Kingpin: Life of Crime"))
    print(_("A FPS by Xatrix Entertainment"))
    print(_("rsync daemon"))
    print(_("File synchronization utility"))
    print(_("MSN Gaming Zone"))
    print(_("Games using MSN Gaming Zone API"))
    print(_("Network;Games;"))
    print(_("Postal 2"))
    print(_("A FPS by Running with Scissors (uses the Unreal engine)"))
    print(_("Globulation 2"))
    print(_("A RTS"))
    print(_("Icecast"))
    print(_("Icecast stream"))
    print(_("Network;Audio Video;"))
    print(_("Icecast - 8000:8001/tcp"))
    print(_("Icecast with SHOUTcast-compatible stream"))
    print(_("DXX-Rebirth"))
    print(_("A source port of Descent, the 3D Flying FPS by Outrage Entertainment"))
    print(_("Tor Normal"))
    print(_("Tor anonymity network"))
    print(_("Sid Meier's Alpha Centauri"))
    print(_("SciFi strategy game by Firaxis"))
    print(_("WINE: Starcraft"))
    print(_("A strategy game by Blizzard Entertainment"))
    print(_("Frostwire"))
    print(_("Frostwire peer-peer file sharing on default port"))
    print(_("Network;File Transfer;P2P;"))
    print(_("Remember to open the ports on the router"))
    print(_("Tribes 2"))
    print(_("A multiplayer combat online game by Dynamix - main port"))
    print(_("Tribes 2 - 28000:29000/tcp/udp"))
    print(_("A multiplayer combat online game by Dynamix, all suggested ports open"))
    print(_("FreeSpace 2"))
    print(_("Space combat simulation by Volition"))
    print(_("Hexen II - 26900/udp"))
    print(_("A fantasy FPS by Raven Software, server on port 27660"))
    print(_("Hexen II - 26901/udp"))
    print(_("A fantasy FPS by Raven Software, server on port 26901"))
    print(_("Hexen II - 26902/udp"))
    print(_("A fantasy FPS by Raven Software, server on port 26902"))
    print(_("Hexen II - 26903/udp"))
    print(_("A fantasy FPS by Raven Software, server on port 26903"))
    print(_("HexenWorld - 26950/udp"))
    print(_("HexenWorld server by Raven Software"))
    print(_("Wakfu"))
    print(_("An online tactical turn-based MMORPG"))
    print(_("Camfrog"))
    print(_("H.323 Call Signaling"))
    print(_("Network;Telephony;Video Conference;"))
    print(_("Scorched 3D server"))
    print(_("A modernization of the classic DOS game Scorched Earth"))
    print(_("Ur-Quan Masters"))
    print(_("An enhanced version of Star Control II from 3DO"))
    print(_("Games;Adventure;"))
    print(_("Steel Storm"))
    print(_("A top-down arcade shooter with hovertanks by Kot-in-Action Creative Artel"))
    print(_("gpsd"))
    print(_("Interface daemon for GPS receivers"))
    print(_("Network;Geography;"))
    print(_("Socks Proxy"))
    print(_("SOCKS protocol for proxy server support"))
    print(_("Network;Services;"))
    print(_("Transparent Proxy"))
    print(_("Transparent proxy"))
    print(_("SSH"))
    print(_("Secure Shell"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC"))
    print(_("Virtual Network Computing"))
    print(_("Network;Remote Access;"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("Railroad Tycoon II"))
    print(_("Railroad strategy game by PopTop Software"))
    print(_("Vuze Remote"))
    print(_("Remote control for Vuze"))
    print(_("Network;P2P;"))
    print(_("Remember to open the ports on the router"))
    print(_("IPP"))
    print(_("Internet Printing Protocol"))
    print(_("Network;Printing;"))
    print(_("FreeLords"))
    print(_("A clone of Warlords"))
    print(_("Dropbox"))
    print(_("File hosting service, that offers cloud storage, file synchronization and client software"))
    print(_("Network;Cloud;"))
    print(_("Serious Sam II"))
    print(_("FPS by Croteam"))
    print(_("NASCAR Racing 2002/03 1 player"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("Games;Simulation;"))
    print(_("NASCAR Racing 2002/03 2 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("NASCAR Racing 2002/03 4 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("NASCAR Racing 2002/03  8 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("NASCAR Racing 2002/03 16 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("NASCAR Racing 2002/03 32 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("NASCAR Racing 2002/03 42 players"))
    print(_("Racing simulators from Papyrus Design Group"))
    print(_("KDE Connect"))
    print(_("Communicate across all your devices"))
    print(_("OpenArena"))
    print(_("A competitive FPS based on ioquake3/id tech 3 engine"))
    print(_("Savage 2: A Tortured Soul"))
    print(_("A RTS/FPS from S2 Games"))
    print(_("DirectX 7"))
    print(_("Network games using DirectX 7 API"))
    print(_("Network;"))
    print(_("DirectX 8"))
    print(_("Network games using DirectX 8 API"))
    print(_("Freeciv"))
    print(_("A turn-based strategy game similar to Civilization I & II by Microprose"))
    print(_("The Battle for Wesnoth"))
    print(_("Turn-based tactical strategy game"))
    print(_("Tremulous"))
    print(_("Team-based SciFi/alien FPS from Dark Legion Development"))
    print(_("Dofus"))
    print(_("A massively multiplayer online role-playing game"))
    print(_("Telnet"))
    print(_("Text-based remote access (like SSH but without the security)"))
    print(_("Telnet is like SSH but without security. It'd be better to use the 'Telnet SSL'"))
    print(_("Telnet TLS/SSL"))
    print(_("Text-based remote access (like SSH but without the security) SSL"))
    print(_("EDuke32"))
    print(_("An enhanced version of Duke Nukem 3D"))
    print(_("Delta Force"))
    print(_("A FPS combat game by NovaLogic"))
    print(_("NFS"))
    print(_("Network File System"))
    print(_("Knights and Merchants TSK"))
    print(_("A RTS by Joymania"))
    print(_("Doomsday"))
    print(_("A source port of id Software's Doom engine which supports Doom, Heretic, and Hexen"))
    print(_("Daimonin"))
    print(_("An open-source MMORPG"))
    print(_("Kerberos v5 KDC"))
    print(_("Kerberos v5 KDC server"))
    print(_("Kerberos v5 admin"))
    print(_("Kerberos v5 server"))
    print(_("Kerberos v5 password"))
    print(_("Kerberos v5 password"))
    print(_("Kerberos v5 Full"))
    print(_("Kerberos v5 server"))
    print(_("LDAP"))
    print(_("LDAP server"))
    print(_("LDAPS"))
    print(_("LDAP server (LDAPS)"))
    print(_("Urban Terror - 27960/udp"))
    print(_("A realistic FPS by Frozen Sand, based on Quake III by id Software, server on port 27660"))
    print(_("Urban Terror - 27961/udp"))
    print(_("A realistic FPS by Frozen Sand, based on Quake III by id Software, server on port 27961"))
    print(_("Urban Terror - 27962/udp"))
    print(_("A realistic FPS by Frozen Sand, based on Quake III by id Software, server on port 27962"))
    print(_("Urban Terror - 27963/udp"))
    print(_("A realistic FPS by Frozen Sand, based on Quake III by id Software, server on port 27963"))
    print(_("Ubuntu One"))
    print(_("Store files online and sync them between computers and mobile devices, as well as stream audio and music from cloud to mobile devices"))
    print(_("Multicast DNS"))
    print(_("Multicast DNS (Avahi, Bonjour)"))
    print(_("Ryzom"))
    print(_("It's also known as The Saga of Ryzom, is a massively multiplayer online role-playing game (MMORPG)"))
    print(_("USB Redirector"))
    print(_("USB device sharing system from INCENTIVES Pro"))
    print(_("Majesty: The Fantasy Kingdom Sim"))
    print(_("A RTS by Cyberlore Studios, ported to Linux by Linux Game Publishing"))
    print(_("YS FLIGHT SIMULATION 2000"))
    print(_("A 3D flight simulator"))
    print(_("Nagios"))
    print(_("Computer system monitor, network monitoring and infrastructure monitoring software application"))
    print(_("System;Monitor;"))
    print(_("Gamer's Internet Tunnel"))
    print(_("IPX network emulator from Morpheus Software"))
    print(_("Enemy Territory: Quake Wars"))
    print(_("A FPS by Splash Damage"))
    print(_("Windows Messenger"))
    print(_("Windows Messenger/Windows Live Messenger application sharing and whiteboard (requires SIP)"))
    print(_("Windows Messenger File"))
    print(_("Windows Messenger/MSN Messenger file transfer"))
    print(_("Windows Messenger Assistance"))
    print(_("Remote Assistance/Remote Desktop Protocol/Terminal Services (RDP)"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("Skype Normal"))
    print(_("Proprietary Voice over IP service and software application"))
    print(_("Neverwinter Nights server"))
    print(_("Default port for Neverwinter Nights, a RPG from Bioware"))
    print(_("Optimized Link State Routing"))
    print(_("A mesh networking protocol"))
    print(_("All Services"))
    print(_("Client, dedicated servers, P2P and voice chat"))
    print(_("Games;Steam;"))
    print(_("Client, Dedicated Servers, P2P and Voice Chat"))
    print(_("Client"))
    print(_("Game client traffic, typically Matchmaking and HLTV and Steam downloads"))
    print(_("Dedicated Servers"))
    print(_("SRCDS Rcon port"))
    print(_("P2P and Voice Chat"))
    print(_("Steamworks P2P Networking and Steam Voice Chat"))
    print(_("Call of Duty"))
    print(_("Additional Ports for Call of Duty: Modern Warfare 2 Multiplayer"))
    print(_("Liquid War"))
    print(_("An original shortest path algorithm and core concept"))
    print(_("hddtemp"))
    print(_("Trivial File Transfer Protocol"))
    print(_("Yet Another Netplay Guider"))
    print(_("YANG - Yet Another Netplay Guider, default game connection"))
    print(_("Games;"))
    print(_("Yet Another Netplay Guider Hosting"))
    print(_("YANG - Yet Another Netplay Guider, room hosting"))
    print(_("DXX-Rebirth on YANG"))
    print(_("DXX-Rebirth, a source port of Descent, connected through YANG"))
    print(_("NSClient++"))
    print(_("Used to monitor Windows machines from a Nagios Server"))
    print(_("Warcraft II Battle.net"))
    print(_("Strategy game by Blizzard Entertainment"))
    print(_("Blood II: The Chosen"))
    print(_("A FPS from Monolith Productions"))
    print(_("XMPP"))
    print(_("Extensible Messaging and Presence Protocol client connection (Jabber)"))
    print(_("Network;Telephony;Instant Messaging;"))
    print(_("XMPP SSL"))
    print(_("Extensible Messaging and Presence Protocol (Jabber) client connection with SSL encryption"))
    print(_("XMPP Interserver"))
    print(_("Extensible Messaging and Presence Protocol server-server connection"))
    print(_("XMPP Serverless"))
    print(_("Extensible Messaging and Presence Protocol link-local messaging/serverless messaging"))
    print(_("FooBillard"))
    print(_("Cue sports simulation with Carambol, Snooker, and Pool"))
    print(_("Games;Sports;"))
    print(_("BitTorrent Minimum"))
    print(_("BitTorrent peer-peer file sharing"))
    print(_("Remember to open the ports on the router"))
    print(_("BitTorrent"))
    print(_("BitTorrent peer-peer file sharing"))
    print(_("Remember to open the ports on the router"))
    print(_("BitTorrent Full"))
    print(_("BitTorrent peer-peer file sharing"))
    print(_("Remember to open the ports on the router"))
    print(_("NFS (jhansonxi)"))
    print(_("Network File System protocol with static ports at relatively unused 4194:4197 (4195 broadcast out)"))
    print(_("NFS Quota (jhansonxi)"))
    print(_("Network File System protocol with filesystem usage quota support with static ports at relatively unused 4194:4198 (4195 broadcast out)"))
    print(_("PennMUSH"))
    print(_("A MUSH/MUD server"))
    print(_("Transmission Daemon"))
    print(_("Remote control for Transmission"))
    print(_("Remember to open the ports on the router"))
    print(_("Hedgewars"))
    print(_("An arcade combat game inspired by Worms from Team17 Software"))
    print(_("Armored Fist 3"))
    print(_("A M1A2 Abrams tank simulation by NovaLogic"))
    print(_("Conquest"))
    print(_("A space warfare game"))
    print(_("Conquest Metaserver"))
    print(_("A space warfare game"))
    print(_("NRPE Nagios Plugin"))
    print(_("Remote Plugin Executor"))
    print(_("UFO: Alien Invasion"))
    print(_("An open-source 3D RTS inspired by X-COM"))
    print(_("WINE: Warcraft III"))
    print(_("A strategy game by Blizzard Entertainment"))
    print(_("WINE: Warcraft III all ports"))
    print(_("Warcraft III with 6112-6119 TCP ports open"))
    print(_("Unreal Tournament 2004"))
    print(_("A FPS by Epic Games"))
    print(_("Unreal Tournament 2004 Admin"))
    print(_("Web-based administration for the FPS by Epic Games"))
    print(_("UPnP"))
    print(_("Universal Plug and Play. It is a framework which can be used to make networked applications"))
    print(_("System;General;"))
    print(_("Joint Operations: Typhoon Rising"))
    print(_("A FPS combat game by NovaLogic"))
    print(_("TeamViewer"))
    print(_("Remote control, desktop sharing, online meetings, web conferencing and file transfer between computers"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("FTP"))
    print(_("File Transfer Protocol"))
    print(_("Wormux"))
    print(_("An arcade combat game inspired by Worms from Team17 Software"))
    print(_("Abuse"))
    print(_("A dark 2D side-scrolling platform game developed by Crack dot Com"))
    print(_("GNUMP3d"))
    print(_("An audio streaming server"))
    print(_("Network;Audio Video;Audio;"))
    print(_("CUPS"))
    print(_("Modular printing system for Unix-like computer operating systems"))
    print(_("Tachyon: The Fringe"))
    print(_("A 3D space combat game by NovaLogic"))
    print(_("Murmur"))
    print(_("Murmur voice chat server (counterpart to Mumble client)"))
    print(_("Balazar III"))
    print(_("A 2D/3D dungeon adventure game"))
    print(_("Postfix Mail Server SMTP"))
    print(_("Postfix is a high-performance mail transport agent"))
    print(_("Postfix Mail Server SMTPS"))
    print(_("Postfix is a high-performance mail transport agent"))
    print(_("Postfix Mail Server Submission"))
    print(_("Postfix is a high-performance mail transport agent"))
    print(_("Minecraft"))
    print(_("A 3D sandbox construction game by Markus Persson"))
    print(_("Myth II: Soulblighter"))
    print(_("A real-time tactics game from Bungie"))
    print(_("Aleph One"))
    print(_("An enhanced port of Marathon 2: Durandal from Bungie Software"))
    print(_("DOSBox IPX"))
    print(_("DOS system emulator"))
    print(_("System;Emulator;"))
    print(_("DOSBox Modem"))
    print(_("DOS system emulator"))
    print(_("Frozen Bubble"))
    print(_("A clone of Puzzle Bobble/Bust-a-Move"))
    print(_("Syslog"))
    print(_("System logging"))
    print(_("System;"))
    print(_("OpenMeetings Secure RTMP"))
    print(_("OpenMeetings Real Time Messaging Protocol over SSL"))
    print(_("Network;Video Conference;"))
    print(_("OpenMeetings Tunneled RTMP"))
    print(_("OpenMeetings Real Time Messaging Protocol over HTTP"))
    print(_("OpenMeetings HTTP"))
    print(_("OpenMeetings HTTP server"))
    print(_("OpenMeetings DSP"))
    print(_("OpenMeetings Desktop Sharing Protocol (ODSP)"))
    print(_("IRC - 194/tcp"))
    print(_("Internet Relay Chat on official port 194 (rarely used)"))
    print(_("Network;IRC;"))
    print(_("IRC"))
    print(_("Internet Relay Chat on common default port 6667, using nf_conntrack_irc DCC helper"))
    print(_("IRC SSL"))
    print(_("Internet Relay Chat on SSL default port 6697"))
    print(_("Shogo: Mobile Armour Division"))
    print(_("A FPS by Monolith Productions"))
    print(_("Armagetron Advanced"))
    print(_("A 3D clone of the Light Cycle game in Tron"))
    print(_("The Mana World"))
    print(_("A fantasy MMORPG"))
    print(_("Teeworlds"))
    print(_("An open source sidescrolling multiplayer shooting game"))
    print(_("Thousand Parsec"))
    print(_("A common framework for building turn based space empire building games"))
    print(_("Thousand Parsec SSL"))
    print(_("A common framework for building turn based space empire building games"))
    print(_("Thousand Parsec Admin"))
    print(_("A common framework for building turn based space empire building games"))
    print(_("DAAP"))
    print(_("Digital Audio Access Protocol"))
    print(_("Subversion Server"))
    print(_("Subversion server for access to Subversion repositories"))
    print(_("MiG-29 Fulcrum"))
    print(_("A Mikoyan-Gurevich MiG-29 Fulcrum simulation by NovaLogic"))
    print(_("D2X-XL"))
    print(_("A source port of Descent II, the 3D Flying FPS by Outrage Entertainment"))
    print(_("Legends"))
    print(_("A FPS based on the Torque Engine"))
    print(_("XBMC Remote"))
    print(_("Remote control for XBMC"))
    print(_("Quake"))
    print(_("A FPS by id Software"))
    print(_("QuakeWorld"))
    print(_("An enhanced multiplayer version of Quake by id Software"))
    print(_("Diablo"))
    print(_("Fantasy combat game by Blizzard Entertainment"))
    print(_("VLC HTTP stream"))
    print(_("VLC media player HTTP stream default port"))
    print(_("Audio Video;"))
    print(_("VLC MMS HTTP stream"))
    print(_("VLC media player Microsoft Media Server stream over HTTP (Windows Media HTTP Streaming Protocol/MS-WMSP) default port"))
    print(_("VLC RTP stream"))
    print(_("VLC media player Real-time Transport Protocol default port"))
    print(_("VLC UDP stream"))
    print(_("VLC media player User Datagram Protocol default port"))
    print(_("Icecast stream"))
    print(_("VLC media player Icecast stream default port"))
    print(_("RTMP Real Time Messaging Protocol"))
    print(_("Real Time Messaging Protocol (Adobe Flash)"))
    print(_("NFS TLDP NFS"))
    print(_("Network File System protocol with static ports at 32765:32768 (some conflicts with popular games)"))
    print(_("NFS Quota & TLDP NFS"))
    print(_("NFS with user/group filesystem usage quota support with static ports at 32765:32769 (some conflicts with popular games)"))
    print(_("Asterisk"))
    print(_("An open source telephony switching and private branch exchange service"))
    print(_("Review that ports are the same in /etc/asterisk/rtp.conf"))
    print(_("DHCP"))
    print(_("Dynamic Host Configuration Protocol"))
    print(_("usbip"))
    print(_("A Peripheral Bus Extension for Device Sharing over IP Network"))
    print(_("Savage: The Battle for Newerth/Savage XR"))
    print(_("A RTS/FPS from S2 Games"))
    print(_("Steam"))
    print(_("Software distribution service and game server browser from Valve"))
    print(_("For Steam Client see the category: Games / Steam"))
    print(_("hddtemp"))
    print(_("Data storage device temperature data server"))
    print(_("Alien Arena"))
    print(_("A SciFi competitive FPS based on the CRX/id Tech 2 engine"))
    print(_("Serious Sam"))
    print(_("FPS by Croteam"))
    print(_("monopd"))
    print(_("A game server for Monopoly-like board games"))
    print(_("Games;Board;"))
    print(_("Doom3"))
    print(_("A FPS by id Software"))
    print(_("OpenTTD server"))
    print(_("An enhanced clone of Chris Sawyer's Transport Tycoon Deluxe"))
    print(_("Delta Force: BHD"))
    print(_("Black Hawk Down. A FPS combat game by NovaLogic"))
    print(_("Warzone 2100"))
    print(_("A RTS game by Pumpkin Studios"))
    print(_("Heavy Gear II"))
    print(_("A mech FPS based on the Dream Pod 9 universe from Activision and Loki Software"))
    print(_("STUN"))
    print(_("Session Traversal Utilities for NAT"))
    print(_("STUN TLS"))
    print(_("Session Traversal Utilities for NAT with TLS encryption"))
    print(_("Spring game engine"))
    print(_("An enhanced clone of RTS game Total Annihilation by Cavedog Entertainment"))
    print(_("0verkill"))
    print(_("An ASCII-art 2D deathmatch game"))
    print(_("Mumble"))
    print(_("A voice chat application for groups"))
    print(_("Doom II"))
    print(_("A FPS by id Software"))
    print(_("Nicotine"))
    print(_("Nicotine is a SoulSeek client written in Python, based on the PySoulSeek project"))
    print(_("Remember to open the ports on the router"))
    print(_("Blobby Volley 2"))
    print(_("A volleyball game"))
    print(_("Heretic II"))
    print(_("Fantasy combat FPS by Raven Software"))
    print(_("GGZ Gaming Zone"))
    print(_("Network support for GNOME Games"))
    print(_("Games for Windows - Live"))
    print(_("Network games using Games for Windows - Live API"))
    print(_("Firefly Media Server"))
    print(_("DAAP audio server formerly known as mt-daapd"))
    print(_("Tether"))
    print(_("A clone of strategy game Moonbase Commander by Humongous Entertainment"))
    print(_("LPD"))
    print(_("LPD server"))
    print(_("MPD"))
    print(_("Music Player Daemon. A server for streaming music"))
    print(_("Snowball Surprise (SnowballZ)"))
    print(_("A RTS snowball fight"))
    print(_("KTorrent"))
    print(_("Feature rich BitTorrent client by KDE"))
    print(_("Remember to open the ports on the router"))
    print(_("Kohan: Immortal Sovereigns"))
    print(_("A real-time strategy game by TimeGate Studios"))
    print(_("AMANDA"))
    print(_("Backup server from Zmanda; standard port with nf_conntrack_amanda"))
    print(_("Network;Archiving;"))
    print(_("Quake 4"))
    print(_("A FPS by id Software"))
    print(_("Yura.net Domination (jRisk)"))
    print(_("A clone of Risk"))
    print(_("SAMBA"))
    print(_("SMB/CIFS protocol for Unix systems, allowing you to serve files and printers to Windows, NT, OS/2 and DOS clients"))
    print(_("Network;Services;|Network;File Transfer"))
    print(_("F-22 Raptor"))
    print(_("A F-22 Raptor simulation by NovaLogic"))
    print(_("TeamSpeak 3"))
    print(_("TeamSpeak 3 voice service"))
    print(_("TeamSpeak 3 File"))
    print(_("TeamSpeak 3 file transfer"))
    print(_("TeamSpeak 3 Query"))
    print(_("TeamSpeak 3 TCP query"))
    print(_("Assault Cube"))
    print(_("A free, multiplayer, first-person shooter game"))
    print(_("PLEX"))
    print(_("Plex Media Server (Main port)"))
    print(_("PLEX DLNA"))
    print(_("Access to the Plex DLNA Server"))
    print(_("PLEX Companion"))
    print(_("Controlling Plex Home Theater via Plex Companion"))
    print(_("PLEX Avahi discovery"))
    print(_("Older Bonjour/Avahi network discovery"))
    print(_("PLEX Roku"))
    print(_("Controlling Plex for Roku via Plex Companion"))
    print(_("PLEX GDM"))
    print(_("GDM network discovery"))
    print(_("PLEX DLNA Server (Other port)"))
    print(_("Another port for Plex DLNA Server"))
    print(_("0 A.D."))
    print(_("A free/open-source RTS game of ancient warfare from Wildfire Games"))
    print(_("Dropbox LanSync"))
    print(_("A web-based file hosting service"))
    print(_("SEDS Serious Sam"))
    print(_("Dedicated server for the FPS by Croteam"))
    print(_("SEDS Remote Admin"))
    print(_("Default remote administration Telnet port for Serious Engine dedicated server"))
    print(_("SEDS - port 25601"))
    print(_("Dedicated server for the FPS by Croteam, alternate game port 25601"))
    print(_("SEDS Admin - port 25600"))
    print(_("Alternate 25600 remote administration Telnet port for Serious Engine dedicated server"))
    print(_("Evil Islands: CotLS"))
    print(_("A RTS game with RPG and stealth elements from Nival Interactive"))
    print(_("Toribash - 20184"))
    print(_("A fighting game based on the physics sandbox model with customizable moves"))
    print(_("Toribash - 20185"))
    print(_("A fighting game based on the physics sandbox model with customizable moves"))
    print(_("Toribash - 20186"))
    print(_("A fighting game based on the physics sandbox model with customizable moves"))
    print(_("Toribash - 20187"))
    print(_("A fighting game based on the physics sandbox model with customizable moves"))
    print(_("Toribash Full"))
    print(_("A fighting game based on the physics sandbox model with customizable moves"))
    print(_("NTP"))
    print(_("Network Time Protocol"))
    print(_("Network;Time;"))
    print(_("Nexuiz"))
    print(_("A FPS based on Darkplaces/Quake engine by id Software"))
    print(_("FreeCol"))
    print(_("A turn-based strategy game similar to Colonization by Microprose"))
    print(_("BZFlag"))
    print(_("A FPS tank battle capture the flag game"))
    print(_("Vuze"))
    print(_("BitTorrent client used to transfer files via the BitTorrent protocol. Vuze uses the Azureus Engine"))
    print(_("You need to add the main random port too that you selected the first time"))
    print(_("NFS (Chris Lowth)"))
    print(_("Network File System protocol with static ports at 4000:4002 (some conflicts with popular games; statd broadcast on random port)"))
    print(_("NFS Quota (Chris Lowth)"))
    print(_("NFS with user/group filesystem usage quota support with static ports at 4000:4003 (some conflicts with popular games; statd broadcast on random port)"))
    print(_("DEFCON"))
    print(_("A thermo-nuclear war strategy game from Introversion Software"))
    print(_("Red Eclipse"))
    print(_("An open source first-person shooter that runs on the Cube Engine 2"))
    print(_("PvPGN"))
    print(_("Player vs Player Gaming Network server emulation based on bnetd"))
    print(_("PvPGN Address Translation"))
    print(_("Player vs Player Gaming Network Address translation port"))
    print(_("Quake III - 27960/udp"))
    print(_("A FPS by id Software, server on port 27660"))
    print(_("Quake III - 27961/udp"))
    print(_("A FPS by id Software, server on port 27961"))
    print(_("Quake III - 27962/udp"))
    print(_("A FPS by id Software, server on port 27962"))
    print(_("Quake III - 27963/udp"))
    print(_("A FPS by id Software, server on port 27963"))
    print(_("POP3"))
    print(_("Post Office Protocol"))
    print(_("POP3S"))
    print(_("Secure mail server"))
    print(_("IMAP"))
    print(_("Internet Message Access Protocol"))
    print(_("IMAPS"))
    print(_("Secure mail server"))
    print(_("SMTP"))
    print(_("Simple Mail Transfer Protocol"))
    print(_("People Nearby"))
    print(_("People Nearby (Bonjour/Salut) functionality in Empathy"))
    print(_("Bonjour"))
    print(_("Bonjour protocol"))
    print(_("MSN Chat"))
    print(_("MSN chat protocol (with file transfer and voice)"))
    print(_("MSN Chat (SSL)"))
    print(_("MSN chat protocol SSL"))
    print(_("AIM Talk"))
    print(_("AIM talk protocol"))
    print(_("Yahoo Chat"))
    print(_("Yahoo chat protocol"))
    print(_("MegaMek"))
    print(_("A unofficial online BattleTech game"))
    print(_("Games;Strategy;Java;"))
    print(_("Chocolate Doom"))
    print(_("A Doom source port that accurately reproduces the experience of Doom as it was played in the 1990s"))
    print(_("PulseAudio"))
    print(_("Networked sound server"))
    print(_("XPilot"))
    print(_("A 2D space combat game"))
    print(_("XPilot 2-players"))
    print(_("A 2D space combat game"))
    print(_("XPilot 4-players"))
    print(_("A 2D space combat game"))
    print(_("XPilot 8-players"))
    print(_("A 2D space combat game"))
    print(_("XPilot 16-players"))
    print(_("A 2D space combat game"))
    print(_("Vendetta Online"))
    print(_("A twitch-based, science fiction massively multiplayer online role-playing game (MMORPG)"))
    print(_("Comanche 4"))
    print(_("A Comanche RAH-66 helicopter simulation by NovaLogic"))
    print(_("Quake II"))
    print(_("A FPS by id Software"))
    print(_("Dark Horizons: LI"))
    print(_("Lore Invasion. A mech-style FPS by Max Gaming Technologies using the Torque Game Engine"))
    print(_("ThinkTanks"))
    print(_("A 3D tank combat game by BraveTree Productions using the Torque Game Engine"))
    print(_("ChromeCast"))
    print(_("Google Stream device"))
    print(_("RDP"))
    print(_("Remote Desktop Protocols"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("Transmission"))
    print(_("BitTorrent client which features a simple interface on top of a cross-platform backend"))
    print(_("Remember to open the ports on the router"))
    print(_("Drakan: Order of the Flame"))
    print(_("A dragon-riding action-adventure from Surreal Software"))
    print(_("HPLIP"))
    print(_("HP Linux Imaging and Printing"))
    print(_("Pioneers"))
    print(_("A game based on The Settlers of Catan by Klaus Teuber"))
    print(_("Pioneers Metaserver"))
    print(_("Metaserver for Pioneers"))
    print(_("F-22 Lightning 3"))
    print(_("A F-22 Raptor simulation by NovaLogic"))
    print(_("World of Padman - 27960/udp"))
    print(_("A FPS by Padworld Entertainment based on Quake III, server on port 27960"))
    print(_("World of Padman - 27961/udp"))
    print(_("A FPS by Padworld Entertainment based on Quake III, server on port 27961"))
    print(_("World of Padman - 27962/udp"))
    print(_("A FPS by Padworld Entertainment based on Quake III, server on port 27962"))
    print(_("World of Padman - 27963/udp"))
    print(_("A FPS by Padworld Entertainment based on Quake III, server on port 27963"))
    print(_("SSDP"))
    print(_("Simple Service Discovery Protocol"))
    print(_("OpenRPG"))
    print(_("A map/chat/dice-rolling tool to allow players to play tabletop games on-line"))
    print(_("Clonk"))
    print(_("An action/RTS/platform game by RedWolf Design; standard ports"))
    print(_("Clonk Host"))
    print(_("An action/RTS/platform game by RedWolf Design; host ports"))
    print(_("Clonk LAN"))
    print(_("An action/RTS/platform game by RedWolf Design; LAN game discovery port"))
    print(_("ManiaDrive game server"))
    print(_("A clone of TrackMania from Nadeo"))
    print(_("ManiaDrive HTTP server "))
    print(_("ManiaDrive/Raydium game monitor HTTP server"))
    print(_("GameSpy"))
    print(_("GameSpy"))
    print(_("GameSpy Arcade"))
    print(_("GameSpy Arcade gaming network"))
    print(_("Bitwig"))
    print(_("Multi-platform music-creation system for production, performance and DJing"))
    print(_("Audio Video;Music;"))
    print(_("Deluge Torrent"))
    print(_("Cross-platform BitTorrent client written with Python and GTK+"))
    print(_("Remember to open the ports on the router"))
    print(_("Amule"))
    print(_("Free peer-to-peer file sharing application that works with the EDonkey network and the Kad network"))
    print(_("Remember to open the ports on the router"))
    print(_("Sacred - port 2005"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Sacred - ports 2005:2006"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Sacred - ports 2005:2007"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Sacred - ports 2005:2008"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Sacred - ports 2005:2009"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Sacred - ports 2005:2010"))
    print(_("Server port for the fantasy RPG by Ascaron Entertainment"))
    print(_("Castle Vox"))
    print(_("A simultaneous-turns strategy game from Sillysoft influenced by Diplomacy and Axis & Allies"))
    print(_("Return To Castle Wolfenstein"))
    print(_("WWII FPS and sequel from Splash Damage, Gray Matter Interactive, Nerve Software, and id Software"))
    print(_("Delta Force: TFD"))
    print(_("Task Force Dagger. A FPS combat game by NovaLogic"))
    print(_("DNS"))
    print(_("Domain Name System"))
    print(_("Battlefield 1942"))
    print(_("A WWII FPS from Digital Illusions CE"))
    print(_("Battlefield 1942 Console"))
    print(_("The RemoteConsole administration tool for Battlefield 1942"))
    print(_("SANE scanner"))
    print(_("Scanner Access Now Easy - scanner sharing server"))
    print(_("Delta Force: LW"))
    print(_("Land Warrior. A FPS combat game by NovaLogic"))
    print(_("SANE scanner"))
    print(_("Scanner Access Now Easy - scanner sharing server"))
    print(_("Network;Scanning;"))
    print(_("SANE Manual"))
    print(_("Scanner Access Now Easy - scanner sharing server, manual ports without nf_conntrack_sane module"))
    print(_("LBreakout2 - 8001/udp"))
    print(_("A Breakout clone"))
    print(_("LBreakout2 - 2002/udp"))
    print(_("A Breakout clone"))
    print(_("Prey"))
    print(_("A SciFi FPS action adventure by 3D Realms"))
    print(_("Heroes of Might and Magic III"))
    print(_("A fantasy strategy game by 3DO"))
    print(_("Delta Force 2"))
    print(_("A FPS combat game by NovaLogic"))
    print(_("London Law"))
    print(_("An online multiplayer adaptation of the Scotland Yard board game"))
    print(_("FTP"))
    print(_("File Transfer Protocol"))
    print(_("NAT"))
    print(_("Port Mapping Protocol"))
    print(_("Rune"))
    print(_("A third-person fantasy combat game by Human Head Studios"))
    print(_("Rune admin"))
    print(_("Web-based administration for the Rune game by Human Head Studios"))
    print(_("qBittorrent"))
    print(_("Cross-platform BitTorrent client GUI written with Qt4"))
    print(_("Remember to open the ports on the router"))
    print(_("Full Metal Soccer server"))
    print(_("A soccer game played with tanks by QuantiCode"))
    print(_("Full Metal Soccer ranking server"))
    print(_("A soccer game played with tanks by QuantiCode"))
    print(_("Full Metal Soccer master server"))
    print(_("A soccer game played with tanks by QuantiCode"))
    print(_("Warsow"))
    print(_("A competitive FPS based on the Qfusion 3D/id tech 2 engine"))
    print(_("Bos Wars"))
    print(_("A futuristic RTS based on the Stratagus engine"))
    print(_("Cube 2: Sauerbraten"))
    print(_("A FPS game based on the Cube engine"))
    print(_("GameRanger"))
    print(_("A game server browser from GameRanger Technologies"))
    print(_("Vibe Streamer"))
    print(_("A free MP3 streaming server"))
    print(_("Lux"))
    print(_("Delux, Ancient Empires and American History: A turn-based strategy game from Sillysoft influenced by Risk"))
    print(_("Delta Force: Xtreme"))
    print(_("A FPS combat game by NovaLogic"))
    print(_("F-16 Multirole Fighter"))
    print(_("A F-16 simulation by NovaLogic"))
    print(_("H.323 Call Signaling"))
    print(_("H.323 Call Signaling"))
    print(_("H.323 discovery"))
    print(_("H.323 multicast gatekeeper discovery (H.225)"))
    print(_("H.323 RAS"))
    print(_("H.323 Gatekeeper Registration, Admission and Status (H.225)"))
    print(_("Glest"))
    print(_("A free, open source 3D RTS game server"))
    print(_("HTTP"))
    print(_("WWW standard protocol on port 80/tcp (IANA/Debian www, http)"))
    print(_("HTTPS"))
    print(_("WWW standard protocol with SSL/TLS on port 443/tcp (IANA https)"))
    print(_("HTTP - 8008/tcp"))
    print(_("WWW standard protocol on port 8008/tcp (IANA http-alt)"))
    print(_("Web Server (HTTP,HTTPS)"))
    print(_("Web Server (HTTP,HTTPS)"))
    print(_("Web Server (8080)"))
    print(_("Web Server (8080)"))
    print(_("HTTP - 8090/tcp"))
    print(_("WWW standard protocol on port 8090/tcp (IANA unassigned, commonly http_alt_alt)"))
    print(_("UPS Tools daemon"))
    print(_("Network UPS Tools"))
    print(_("MySQL"))
    print(_("MySQL Database"))
    print(_("Office;Database;"))
    print(_("Kali"))
    print(_("Internet game browser and IPX network emulator"))
    print(_("Dopewars"))
    print(_("A FPS by id Software"))
    print(_("VNC server display :0"))
    print(_("Virtual Network Computing standard server display :0"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:1"))
    print(_("Virtual Network Computing standard server displays :0 through :1"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:3"))
    print(_("Virtual Network Computing standard server displays :0 through :3"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:7"))
    print(_("Virtual Network Computing standard server displays :0 through :7"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC http server display :0"))
    print(_("Virtual Network Computing http server display :0"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:1"))
    print(_("Virtual Network Computing http server displays :0 through :1"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:3"))
    print(_("Virtual Network Computing http server displays :0 through :3"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("VNC displays :0-:7"))
    print(_("Virtual Network Computing http server displays :0 through :7"))
    print(_("It may be a security risk to use a default allow policy"))
    print(_("SiN"))
    print(_("A FPS by Ritual Entertainment"))
    print(_("Webcam_server"))
    print(_("A webcam viewer for web servers with an optional Java-based viewer"))
    print(_("Network;Audio Video;Video;"))
    print(_("Tremulous"))
    print(_("A free and open source team-based first-person shooter with real-time strategy elements"))
    print(_("Sid Meier's Civilization IV"))
    print(_("A turn-based strategy game from Firaxis Games"))
    print(_("Authentication is required to run the Firewall Configuration"))
    print(_("Firewall Configuration"))
    print(_("An easy way to configure your firewall"))
